<?php

namespace Litecms\Faqscat\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Faqscat\Models\Faqscat;

class FaqscatPolicy
{

    /**
     * Determine if the given user can view the faqscat.
     *
     * @param UserPolicy $user
     * @param Faqscat $faqscat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Faqscat $faqscat)
    {
        if ($user->canDo('faqscat.faqscat.view') && $user->isAdmin()) {
            return true;
        }

        return $faqscat->user_id == user_id() && $faqscat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faqscat.
     *
     * @param UserPolicy $user
     * @param Faqscat $faqscat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faqscat.faqscat.create');
    }

    /**
     * Determine if the given user can update the given faqscat.
     *
     * @param UserPolicy $user
     * @param Faqscat $faqscat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Faqscat $faqscat)
    {
        if ($user->canDo('faqscat.faqscat.edit') && $user->isAdmin()) {
            return true;
        }

        return $faqscat->user_id == user_id() && $faqscat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faqscat.
     *
     * @param UserPolicy $user
     * @param Faqscat $faqscat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Faqscat $faqscat)
    {
        return $faqscat->user_id == user_id() && $faqscat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faqscat.
     *
     * @param UserPolicy $user
     * @param Faqscat $faqscat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Faqscat $faqscat)
    {
        if ($user->canDo('faqscat.faqscat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faqscat.
     *
     * @param UserPolicy $user
     * @param Faqscat $faqscat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Faqscat $faqscat)
    {
        if ($user->canDo('faqscat.faqscat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
